@@ -128,7 +128,16 @@ void FileImpl::flush() {
     return;
   }
 
-  BOOL succeeded = ::FlushViewOfFile(addr_, size_);
+  BOOL succeeded = ::FlushViewOfFile(addr_, static_cast<SIZE_T>(size_));
+  GRN_DAT_THROW_IF(IO_ERROR, !succeeded);
+
+  SYSTEMTIME system_time;
+  GetSystemTime(&system_time);
+  FILETIME file_time;
+  succeeded = SystemTimeToFileTime(&system_time, &file_time);
+  GRN_DAT_THROW_IF(IO_ERROR, !succeeded);
+
+  succeeded = SetFileTime(file_, NULL, NULL, &file_time);
   GRN_DAT_THROW_IF(IO_ERROR, !succeeded);
 }
 
