@@ -64,8 +64,6 @@ GRN_API grn_rc grn_db_close(grn_ctx *ctx, grn_obj *db);
 
 grn_obj *grn_db_keys(grn_obj *s);
 
-uint32_t grn_db_lastmod(grn_obj *s);
-
 grn_rc _grn_table_delete_by_id(grn_ctx *ctx, grn_obj *table, grn_id id,
                                grn_table_delete_optarg *optarg);
 
@@ -187,6 +185,7 @@ struct _grn_proc {
     struct {
       grn_scorer_score_func *score;
     } scorer;
+    grn_window_function_func *window_function;
   } callbacks;
 
   void *user_data;
@@ -214,7 +213,7 @@ GRN_API grn_obj *grn_proc_get_or_add_var(grn_ctx *ctx, grn_user_data *user_data,
                                          const char *name, unsigned int name_size);
 
 GRN_API grn_obj *grn_proc_alloc(grn_ctx *ctx, grn_user_data *user_data,
-                                grn_id domain, grn_obj_flags flags);
+                                grn_id domain, unsigned char flags);
 
 GRN_API grn_rc grn_proc_call(grn_ctx *ctx, grn_obj *proc,
                              int nargs, grn_obj *caller);
@@ -432,9 +431,12 @@ GRN_API grn_rc grn_column_filter(grn_ctx *ctx, grn_obj *column,
                                  grn_obj *value, grn_obj *result_set,
                                  grn_operator set_op);
 
-grn_rc grn_accessor_resolve(grn_ctx *ctx, grn_obj *accessor, int deep,
-                            grn_obj *base_res, grn_obj **res,
-                            grn_search_optarg *optarg);
+grn_rc grn_accessor_resolve(grn_ctx *ctx,
+                            grn_obj *accessor,
+                            int deep,
+                            grn_obj *base_res,
+                            grn_obj *res,
+                            grn_operator op);
 
 typedef struct {
   grn_id target;
