@@ -83,7 +83,28 @@ object_get_name(mrb_state *mrb, mrb_value self)
   object = DATA_PTR(self);
   name_length = grn_obj_name(ctx, object, name, GRN_TABLE_MAX_KEY_SIZE);
 
-  return mrb_str_new(mrb, name, name_length);
+  if (name_length == 0) {
+    return mrb_nil_value();
+  } else {
+    return mrb_str_new(mrb, name, name_length);
+  }
+}
+
+static mrb_value
+object_get_path(mrb_state *mrb, mrb_value self)
+{
+  grn_ctx *ctx = (grn_ctx *)mrb->ud;
+  grn_obj *object;
+  const char *path;
+
+  object = DATA_PTR(self);
+  path = grn_obj_path(ctx, object);
+
+  if (path) {
+    return mrb_str_new_cstr(mrb, path);
+  } else {
+    return mrb_nil_value();
+  }
 }
 
 static mrb_value
@@ -253,6 +274,7 @@ grn_mrb_object_init(grn_ctx *ctx)
 
   mrb_define_method(mrb, klass, "id", object_get_id, MRB_ARGS_NONE());
   mrb_define_method(mrb, klass, "name", object_get_name, MRB_ARGS_NONE());
+  mrb_define_method(mrb, klass, "path", object_get_path, MRB_ARGS_NONE());
   mrb_define_method(mrb, klass, "grn_inspect",
                     object_grn_inspect, MRB_ARGS_NONE());
   mrb_define_method(mrb, klass, "==", object_equal, MRB_ARGS_REQ(1));
