@@ -41,12 +41,6 @@ export GRN_QUERY_EXPANDER_TSV_SYNONYMS_FILE
 GRN_RUBY_SCRIPTS_DIR="$top_dir/lib/mrb/scripts"
 export GRN_RUBY_SCRIPTS_DIR
 
-: ${GRN_MECAB_CHUNKED_TOKENIZE_ENABLED:="yes"}
-export GRN_MECAB_CHUNKED_TOKENIZE_ENABLED
-
-: ${GRN_MECAB_CHUNK_SIZE_THRESHOLD:="30"}
-export GRN_MECAB_CHUNK_SIZE_THRESHOLD
-
 case `uname` in
   Linux|*BSD)
     LD_LIBRARY_PATH="$top_dir/lib/.libs:$LD_LIBRARY_PATH"
